// Ben Clewett, April 2004
//
// Wrapper for SQLite to return a query as a table in memory.
//
// There is no warrenty, the code provided for illistation reasons only. Any user withing to make use of this does so at their own risk.

#ifndef SQLITE_WRAPPER
#define SQLITE_WRAPPER

#define HERE printf("%d@%s:HERE\n", __LINE__, __FILE__); fflush(stdout);

#include "sqlite3.h"

// Data structures:

// Meta data.  Column name and type:
typedef struct {
	unsigned char type;
	char *name;
} lw_meta_data;

// Each cell of data in a linked-list.
// 'NULL' = NULL pointer
// All data as text.
typedef struct {
	const unsigned char *data;
	void *next;
} lw_cell_data;

// Result set.
// Access to linked list by linked list or by
// an array:
typedef struct {
	unsigned int col_count;
	unsigned int row_count;
	lw_cell_data **cell_array;
	lw_cell_data *cell_list;
	lw_meta_data *meta_data;
} lw_result;

// Main call:
// NULL = error
lw_result *lw_query(sqlite3 *handle, const char *query);

// Error interrogation:
int lw_get_errno();
const char *lw_get_errmsg();

// Free result
void lw_free_result(lw_result *result);

// Get cell data:
unsigned char lw_is_null(lw_result *result, unsigned int row, unsigned int col);
const unsigned char *lw_cell(lw_result *result, unsigned int row, unsigned int col);
int lw_cell_i(lw_result *result, unsigned int row, unsigned int col);
double lw_cell_d(lw_result *result, unsigned int row, unsigned int col);

// Table dimenstiona:
unsigned int lw_col_count(lw_result *);
unsigned int lw_row_count(lw_result *);

// Show table
void lw_show_table(lw_result *result, FILE *);
void lw_show_table_cvs(lw_result *result, FILE *);
void lw_show_table_xml(lw_result *result, FILE *, char *table_tag_name, char *row_tag_name);
void lw_show_table_html(lw_result *result, FILE *);



#endif
